@@ -26,6 +26,8 @@
 
 #include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
+#include <gio/gdesktopappinfo.h>
+
 #include <telepathy-glib/util.h>
 
 #include <folks/folks.h>
@@ -37,6 +39,7 @@
 #include <libempathy/empathy-chatroom-manager.h>
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-contact-list.h>
+#include <libempathy/empathy-pkg-kit.h>
 
 #include "empathy-account-selector-dialog.h"
 #include "empathy-individual-menu.h"
@@ -46,10 +49,8 @@
 #include "empathy-gtk-enum-types.h"
 #include "empathy-individual-dialogs.h"
 #include "empathy-individual-edit-dialog.h"
-#include "empathy-individual-information-dialog.h"
 #include "empathy-ui-utils.h"
 #include "empathy-share-my-desktop.h"
-#include "empathy-linking-dialog.h"
 #include "empathy-call-utils.h"
 #include "empathy-individual-store-channel.h"
 
@@ -70,13 +71,6 @@ enum {
   PROP_STORE,
 };
 
-enum {
-  SIGNAL_LINK_CONTACTS_ACTIVATED,
-  LAST_SIGNAL
-};
-
-static guint signals[LAST_SIGNAL];
-
 G_DEFINE_TYPE (EmpathyIndividualMenu, empathy_individual_menu, GTK_TYPE_MENU);
 
 static GtkWidget * empathy_individual_chat_menu_item_new (
@@ -89,8 +83,6 @@ static GtkWidget * empathy_individual_info_menu_item_new (
     FolksIndividual *individual);
 static GtkWidget * empathy_individual_edit_menu_item_new (
     FolksIndividual *individual);
-static GtkWidget * empathy_individual_link_menu_item_new (
-    FolksIndividual *individual);
 static GtkWidget * empathy_individual_invite_menu_item_new (
     FolksIndividual *individual,
     EmpathyContact *contact);
@@ -274,16 +266,6 @@ while_finish:
   g_clear_object (&iter);
 }
 
-static void
-individual_link_menu_item_activate_cb (EmpathyIndividualMenu *self)
-{
-  EmpathyIndividualMenuPriv *priv = GET_PRIV (self);
-  GtkWidget *dialog;
-
-  dialog = empathy_linking_dialog_show (priv->individual, NULL);
-  g_signal_emit (self, signals[SIGNAL_LINK_CONTACTS_ACTIVATED], 0, dialog);
-}
-
 static void
 empathy_individual_menu_init (EmpathyIndividualMenu *self)
 {
@@ -783,8 +765,7 @@ constructed (GObject *object)
   /* Separator */
   if (features & (EMPATHY_INDIVIDUAL_FEATURE_EDIT |
       EMPATHY_INDIVIDUAL_FEATURE_INFO |
-      EMPATHY_INDIVIDUAL_FEATURE_FAVOURITE |
-      EMPATHY_INDIVIDUAL_FEATURE_LINK))
+      EMPATHY_INDIVIDUAL_FEATURE_FAVOURITE))
     {
       item = gtk_separator_menu_item_new ();
       gtk_menu_shell_append (shell, item);
@@ -799,18 +780,6 @@ constructed (GObject *object)
       gtk_widget_show (item);
     }
 
-  /* Link */
-  if (features & EMPATHY_INDIVIDUAL_FEATURE_LINK)
-    {
-      item = empathy_individual_link_menu_item_new (individual);
-      gtk_menu_shell_append (shell, item);
-
-      g_signal_connect_swapped (item, "activate",
-          (GCallback) individual_link_menu_item_activate_cb, object);
-
-      gtk_widget_show (item);
-    }
-
   /* Log */
   if (features & EMPATHY_INDIVIDUAL_FEATURE_LOG)
     {
@@ -956,12 +925,6 @@ empathy_individual_menu_class_init (EmpathyIndividualMenuClass *klass)
           EMPATHY_TYPE_INDIVIDUAL_STORE,
           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS));
 
-  signals[SIGNAL_LINK_CONTACTS_ACTIVATED] =
-      g_signal_new ("link-contacts-activated", G_OBJECT_CLASS_TYPE (klass),
-          G_SIGNAL_RUN_LAST, 0, NULL, NULL,
-          g_cclosure_marshal_generic,
-          G_TYPE_NONE, 1, EMPATHY_TYPE_LINKING_DIALOG);
-
   g_type_class_add_private (object_class, sizeof (EmpathyIndividualMenuPriv));
 }
 
@@ -1291,9 +1254,117 @@ empathy_individual_favourite_menu_item_new (FolksIndividual *individual)
 }
 
 static void
-individual_info_menu_item_activate_cb (FolksIndividual *individual)
+show_gnome_contacts_error_dialog (void)
 {
-  empathy_individual_information_dialog_show (individual, NULL);
+  GtkWidget *dialog;
+
+  dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
+      GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+      _("gnome-contacts not installed"));
+
+  gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+      _("Please install gnome-contacts to access contacts details."));
+
+  g_signal_connect_swapped (dialog, "response",
+          G_CALLBACK (gtk_widget_destroy), dialog);
+
+  gtk_widget_show (dialog);
+}
+
+static void
+start_gnome_contacts (FolksIndividual *individual,
+    gboolean try_installing);
+
+static void
+install_gnome_contacts_cb (GObject *source,
+    GAsyncResult *result,
+    gpointer user_data)
+{
+  FolksIndividual *individual = user_data;
+  GError *error = NULL;
+
+  if (!empathy_pkg_kit_install_packages_finish (result, &error))
+    {
+      DEBUG ("Failed to install gnome-contacts: %s", error->message);
+      g_error_free (error);
+
+      show_gnome_contacts_error_dialog ();
+      goto out;
+    }
+
+  DEBUG ("gnome-contacts installed");
+
+  start_gnome_contacts (individual, FALSE);
+
+out:
+  g_object_unref (individual);
+}
+
+static void
+start_gnome_contacts (FolksIndividual *individual,
+    gboolean try_installing)
+{
+  GDesktopAppInfo *desktop_info;
+  gchar *cmd;
+  GAppInfo *app_info;
+  GError *error = NULL;
+  GdkAppLaunchContext *context = NULL;
+  GdkDisplay *display;
+
+  g_return_if_fail (FOLKS_IS_INDIVIDUAL (individual));
+
+  /* Start gnome-contacts */
+  display = gdk_display_get_default ();
+  context = gdk_display_get_app_launch_context (display);
+
+  desktop_info = g_desktop_app_info_new ("gnome-contacts.desktop");
+  if (desktop_info == NULL)
+    {
+      if (try_installing)
+        {
+          const gchar *packages[] = { "gnome-contacts", NULL };
+
+          DEBUG ("gnome-contacts not installed; try to install it");
+
+          empathy_pkg_kit_install_packages_async (0, packages, NULL,
+              NULL, install_gnome_contacts_cb, g_object_ref (individual));
+        }
+      else
+        {
+          show_gnome_contacts_error_dialog ();
+        }
+
+      return;
+    }
+
+  /* glib doesn't have API to start a desktop file with args... (#637875) */
+  cmd = g_strdup_printf ("%s -i %s", g_app_info_get_commandline (
+        (GAppInfo *) desktop_info), folks_individual_get_id (individual));
+
+  app_info = g_app_info_create_from_commandline (cmd, NULL, 0, &error);
+  if (app_info == NULL)
+    {
+      DEBUG ("Failed to create app_info: %s", error->message);
+      g_error_free (error);
+      return;
+    }
+
+  if (!g_app_info_launch (app_info, NULL, (GAppLaunchContext *) context,
+        &error))
+    {
+      g_critical ("Failed to start gnome-contacts: %s", error->message);
+      g_error_free (error);
+    }
+
+  g_object_unref (desktop_info);
+  g_object_unref (app_info);
+}
+
+static void
+individual_info_menu_item_activate_cb (GtkMenuItem *item,
+    FolksIndividual *individual)
+{
+  start_gnome_contacts (individual, TRUE);
 }
 
 static GtkWidget *
@@ -1312,7 +1383,7 @@ empathy_individual_info_menu_item_new (FolksIndividual *individual)
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
   gtk_widget_show (image);
 
-  g_signal_connect_swapped (item, "activate",
+  g_signal_connect (item, "activate",
           G_CALLBACK (individual_info_menu_item_activate_cb),
           individual);
 
@@ -1370,31 +1441,6 @@ empathy_individual_edit_menu_item_new (FolksIndividual *individual)
   return item;
 }
 
-static GtkWidget *
-empathy_individual_link_menu_item_new (FolksIndividual *individual)
-{
-  GtkWidget *item;
-  /*GtkWidget *image;*/
-
-  g_return_val_if_fail (FOLKS_IS_INDIVIDUAL (individual), NULL);
-
-  item = gtk_image_menu_item_new_with_mnemonic (
-      /* Translators: this is a verb meaning "to connect two contacts together
-       * to form a meta-contact". */
-      C_("Link individual (contextual menu)", "_Link Contacts…"));
-  /* TODO */
-  /*image = gtk_image_new_from_icon_name (GTK_STOCK_EDIT, GTK_ICON_SIZE_MENU);
-  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
-  gtk_widget_show (image);*/
-
-  /* Only allow trusted Individuals to be linked */
-  gtk_widget_set_sensitive (item,
-      folks_individual_get_trust_level (individual) ==
-          FOLKS_TRUST_LEVEL_PERSONAS);
-
-  return item;
-}
-
 typedef struct
 {
   FolksIndividual *individual;
