@@ -28,7 +28,6 @@
 #include <telepathy-glib/account-manager.h>
 #include <telepathy-glib/interfaces.h>
 #include <telepathy-glib/util.h>
-#include <telepathy-yell/telepathy-yell.h>
 
 #include <telepathy-logger/log-manager.h>
 
@@ -1741,8 +1740,7 @@ tp_caps_to_capabilities (TpCapabilities *caps)
           if (!tp_strdiff (service, "rfb"))
             capabilities |= EMPATHY_CAPABILITIES_RFB_STREAM_TUBE;
         }
-      else if (!tp_strdiff (chan_type,
-        TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA))
+      else if (!tp_strdiff (chan_type, TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA))
         {
           guint j;
 
@@ -1769,26 +1767,25 @@ tp_caps_to_capabilities (TpCapabilities *caps)
                 TP_PROP_CHANNEL_INTERFACE_SMS_SMS_CHANNEL, NULL))
             capabilities |= EMPATHY_CAPABILITIES_SMS;
         }
-      else if (!tp_strdiff (chan_type,
-        TPY_IFACE_CHANNEL_TYPE_CALL))
+      else if (!tp_strdiff (chan_type, TP_IFACE_CHANNEL_TYPE_CALL))
         {
           guint j;
 
           if (tp_asv_get_boolean (fixed_prop,
-              TPY_PROP_CHANNEL_TYPE_CALL_INITIAL_AUDIO, NULL))
+              TP_PROP_CHANNEL_TYPE_CALL_INITIAL_AUDIO, NULL))
             capabilities |= EMPATHY_CAPABILITIES_AUDIO;
 
           if (tp_asv_get_boolean (fixed_prop,
-              TPY_PROP_CHANNEL_TYPE_CALL_INITIAL_VIDEO, NULL))
+              TP_PROP_CHANNEL_TYPE_CALL_INITIAL_VIDEO, NULL))
             capabilities |= EMPATHY_CAPABILITIES_VIDEO;
 
           for (j = 0; allowed_prop[j] != NULL; j++)
             {
               if (!tp_strdiff (allowed_prop[j],
-                    TPY_PROP_CHANNEL_TYPE_CALL_INITIAL_AUDIO))
+                    TP_PROP_CHANNEL_TYPE_CALL_INITIAL_AUDIO))
                 capabilities |= EMPATHY_CAPABILITIES_AUDIO;
               else if (!tp_strdiff (allowed_prop[j],
-                    TPY_PROP_CHANNEL_TYPE_CALL_INITIAL_VIDEO))
+                    TP_PROP_CHANNEL_TYPE_CALL_INITIAL_VIDEO))
                 capabilities |= EMPATHY_CAPABILITIES_VIDEO;
             }
         }
