@@ -41,6 +41,7 @@
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-connection-managers.h>
 #include <libempathy/empathy-connectivity.h>
+#include <libempathy/empathy-pkg-kit.h>
 #include <libempathy/empathy-tp-contact-factory.h>
 
 #include <libempathy-gtk/empathy-ui-utils.h>
@@ -51,8 +52,10 @@
 #include <libempathy-gtk/empathy-cell-renderer-activatable.h>
 #include <libempathy-gtk/empathy-contact-widget.h>
 #include <libempathy-gtk/empathy-images.h>
+#include <libempathy-gtk/empathy-local-xmpp-assistant-widget.h>
 #include <libempathy-gtk/empathy-new-account-dialog.h>
 
+#include "empathy-accounts-common.h"
 #include "empathy-accounts-dialog.h"
 #include "empathy-import-dialog.h"
 #include "empathy-import-utils.h"
@@ -78,7 +81,8 @@ G_DEFINE_TYPE (EmpathyAccountsDialog, empathy_accounts_dialog, GTK_TYPE_DIALOG);
 enum
 {
   NOTEBOOK_PAGE_ACCOUNT = 0,
-  NOTEBOOK_PAGE_LOADING
+  NOTEBOOK_PAGE_LOADING,
+  NOTEBOOK_PAGE_NO_PROTOCOL
 };
 
 typedef struct {
@@ -91,7 +95,6 @@ typedef struct {
   GtkWidget *image_status;
   GtkWidget *throbber;
   GtkWidget *enabled_switch;
-  GtkWidget *frame_no_protocol;
 
   GtkWidget *treeview;
 
@@ -99,8 +102,6 @@ typedef struct {
   GtkWidget *button_remove;
   GtkWidget *button_import;
 
-  GtkWidget *hbox_protocol;
-
   GtkWidget *image_type;
   GtkWidget *label_name;
   GtkWidget *label_type;
@@ -212,6 +213,9 @@ accounts_dialog_status_infobar_set_message (EmpathyAccountsDialog *dialog,
 
   message_markup = g_markup_printf_escaped ("<i>%s</i>", message);
   gtk_label_set_markup (GTK_LABEL (priv->label_status), message_markup);
+
+  gtk_widget_set_tooltip_text (priv->label_status, message);
+
   g_free (message_markup);
 }
 
@@ -258,6 +262,21 @@ accounts_dialog_enable_switch_active_cb (GtkSwitch *sw,
       accounts_dialog_enable_account_cb, NULL);
 }
 
+static void
+install_haze_cb (GObject *source,
+    GAsyncResult *result,
+    gpointer user_data)
+{
+  GError *error = NULL;
+
+  if (!empathy_pkg_kit_install_packages_finish  (result, &error))
+    {
+      DEBUG ("Failed to install telepathy-haze: %s", error->message);
+
+      g_error_free (error);
+    }
+}
+
 static void
 accounts_dialog_update_status_infobar (EmpathyAccountsDialog *dialog,
     TpAccount *account)
@@ -275,6 +294,7 @@ accounts_dialog_update_status_infobar (EmpathyAccountsDialog *dialog,
   gboolean                  account_enabled;
   gboolean                  creating_account;
   TpStorageRestrictionFlags storage_restrictions = 0;
+  gboolean display_switch = TRUE;
 
   view = GTK_TREE_VIEW (priv->treeview);
   selection = gtk_tree_view_get_selection (view);
@@ -311,6 +331,13 @@ accounts_dialog_update_status_infobar (EmpathyAccountsDialog *dialog,
         presence = TP_CONNECTION_PRESENCE_TYPE_OFFLINE;
 
       storage_restrictions = tp_account_get_storage_restrictions (account);
+      if (storage_restrictions & TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_ENABLED)
+        display_switch = FALSE;
+
+      /* Butterfly accounts shouldn't be used any more */
+      if (!tp_strdiff (tp_account_get_connection_manager (account),
+            "butterfly"))
+        display_switch = FALSE;
     }
   else
     {
@@ -332,8 +359,7 @@ accounts_dialog_update_status_infobar (EmpathyAccountsDialog *dialog,
       accounts_dialog_enable_switch_active_cb, dialog);
 
   /* Display the Enable switch if account supports it */
-  gtk_widget_set_visible (priv->enabled_switch,
-      !(storage_restrictions & TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_ENABLED));
+  gtk_widget_set_visible (priv->enabled_switch, display_switch);
 
   if (account_enabled)
     {
@@ -423,8 +449,24 @@ accounts_dialog_update_status_infobar (EmpathyAccountsDialog *dialog,
     }
   else
     {
-      accounts_dialog_status_infobar_set_message (dialog,
-          _("Offline — Account Disabled"));
+      if (!tp_strdiff (tp_account_get_connection_manager (account),
+            "butterfly"))
+        {
+          const gchar *packages[] = { "telepathy-haze", NULL };
+
+          accounts_dialog_status_infobar_set_message (dialog,
+              _("This account has been disabled because it relies on an old, "
+                "unsupported backend. Please install telepathy-haze and "
+                "restart your session to migrate the account."));
+
+          empathy_pkg_kit_install_packages_async (0, packages, NULL, NULL,
+              install_haze_cb, NULL);
+        }
+      else
+        {
+          accounts_dialog_status_infobar_set_message (dialog,
+              _("Offline — Account Disabled"));
+        }
 
       gtk_info_bar_set_message_type (GTK_INFO_BAR (priv->infobar),
           GTK_MESSAGE_WARNING);
@@ -980,28 +1022,19 @@ accounts_dialog_update_settings (EmpathyAccountsDialog *dialog,
 
           return;
         }
-      if (empathy_connection_managers_get_cms_num (priv->cms) > 0)
-        {
-          /* We have no account configured but we have some
-           * profiles installed. The user obviously wants to add
-           * an account. Click on the Add button for him. */
-          accounts_dialog_button_add_clicked_cb (priv->button_add,
-              dialog);
-          return;
-        }
 
       /* No account and no profile, warn the user */
       gtk_widget_hide (priv->vbox_details);
-      gtk_widget_show (priv->frame_no_protocol);
       gtk_widget_set_sensitive (priv->button_add, FALSE);
+
+      gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook_account),
+          NOTEBOOK_PAGE_NO_PROTOCOL);
       return;
     }
 
   /* We have an account selected, destroy old settings and create a new
    * one for the account selected */
-  gtk_widget_hide (priv->frame_no_protocol);
   gtk_widget_show (priv->vbox_details);
-  gtk_widget_hide (priv->hbox_protocol);
 
   if (priv->dialog_content)
     {
@@ -1865,6 +1898,7 @@ accounts_dialog_add_account (EmpathyAccountsDialog *dialog,
   const gchar        *name;
   EmpathyAccountsDialogPriv *priv = GET_PRIV (dialog);
   gboolean selected = FALSE;
+  GtkTreeSelection *selection;
 
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->treeview));
   status = tp_account_get_connection_status (account, NULL);
@@ -1872,15 +1906,18 @@ accounts_dialog_add_account (EmpathyAccountsDialog *dialog,
 
   settings = empathy_account_settings_new_for_account (account);
 
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview));
+
   if (!accounts_dialog_get_account_iter (dialog, account, &iter))
     {
+      /* Select the account if it's the first added */
+      if (gtk_tree_selection_count_selected_rows (selection) == 0)
+        selected = TRUE;
+
       gtk_list_store_append (GTK_LIST_STORE (model), &iter);
     }
   else
     {
-      GtkTreeSelection *selection;
-
-      selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview));
       selected = gtk_tree_selection_iter_is_selected (selection, &iter);
     }
 
@@ -2004,15 +2041,24 @@ accounts_dialog_account_enabled_cb (TpAccountManager *manager,
   enable_or_disable_account (dialog, account, TRUE);
 }
 
+static GtkWidget *
+display_import_dialog (EmpathyAccountsDialog *dialog)
+{
+  EmpathyAccountsDialogPriv *priv = GET_PRIV (dialog);
+  GtkWidget *import_dialog;
+
+  import_dialog = empathy_import_dialog_new (GTK_WINDOW (dialog),
+      FALSE, priv->cms);
+  gtk_widget_show (import_dialog);
+
+  return import_dialog;
+}
+
 static void
 accounts_dialog_button_import_clicked_cb (GtkWidget *button,
     EmpathyAccountsDialog *dialog)
 {
-  GtkWidget *import_dialog;
-
-  import_dialog = empathy_import_dialog_new (GTK_WINDOW (dialog),
-      FALSE);
-  gtk_widget_show (import_dialog);
+  display_import_dialog (dialog);
 }
 
 static void
@@ -2047,6 +2093,85 @@ accounts_dialog_set_selected_account (EmpathyAccountsDialog *dialog,
     select_and_scroll_to_iter (dialog, &iter);
 }
 
+static void
+salut_valid_cb (GtkWidget *widget,
+    gboolean valid,
+    GtkWidget *button)
+{
+  gtk_widget_set_sensitive (button, valid);
+}
+
+static void
+maybe_show_salut_dialog (EmpathyAccountsDialog *self)
+{
+  EmpathyAccountsDialogPriv *priv = GET_PRIV (self);
+  GtkWidget *dialog, *widget, *content, *button;
+  gint response;
+
+  if (!empathy_local_xmpp_assistant_widget_should_create_account (
+        priv->account_manager))
+    return;
+
+  widget = empathy_local_xmpp_assistant_widget_new ();
+  gtk_widget_show (widget);
+
+  dialog = gtk_dialog_new ();
+
+  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+
+  gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Skip"),
+      GTK_RESPONSE_NO);
+
+  button = gtk_dialog_add_button (GTK_DIALOG (dialog),
+      _("_Connect"), GTK_RESPONSE_YES);
+  gtk_widget_set_sensitive (button, FALSE);
+
+  g_signal_connect (widget, "valid", G_CALLBACK (salut_valid_cb),
+      button);
+
+  content = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+  gtk_box_pack_start (GTK_BOX (content), widget, TRUE, TRUE, 0);
+
+  response = gtk_dialog_run (GTK_DIALOG (dialog));
+
+  if (response == GTK_RESPONSE_YES)
+    {
+      empathy_local_xmpp_assistant_widget_create_account (
+          EMPATHY_LOCAL_XMPP_ASSISTANT_WIDGET (widget));
+    }
+
+  gtk_widget_destroy (dialog);
+}
+
+static void
+import_dialog_response_cb (GtkDialog *dialog,
+    gint response_id,
+    EmpathyAccountsDialog *self)
+{
+  maybe_show_salut_dialog (self);
+}
+
+static void
+maybe_show_import_dialog (EmpathyAccountsDialog *self)
+{
+  EmpathyAccountsDialogPriv *priv = GET_PRIV (self);
+  GtkWidget *dialog;
+
+  if (empathy_accounts_has_non_salut_accounts (priv->account_manager))
+    return;
+
+  if (!empathy_import_accounts_to_import ())
+    {
+      maybe_show_salut_dialog (self);
+      return;
+    }
+
+  dialog = display_import_dialog (self);
+
+  tp_g_signal_connect_object (dialog, "response",
+      G_CALLBACK (import_dialog_response_cb), self, 0);
+}
+
 static void
 finished_loading (EmpathyAccountsDialog *self)
 {
@@ -2068,6 +2193,8 @@ finished_loading (EmpathyAccountsDialog *self)
   gtk_spinner_stop (GTK_SPINNER (priv->spinner));
   gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook_account),
       NOTEBOOK_PAGE_ACCOUNT);
+
+  maybe_show_import_dialog (self);
 }
 
 static void
@@ -2210,14 +2337,12 @@ accounts_dialog_build_ui (EmpathyAccountsDialog *dialog)
   gui = empathy_builder_get_file (filename,
       "accounts_dialog_hbox", &top_hbox,
       "vbox_details", &priv->vbox_details,
-      "frame_no_protocol", &priv->frame_no_protocol,
       "alignment_settings", &priv->alignment_settings,
       "alignment_infobar", &priv->alignment_infobar,
       "treeview", &priv->treeview,
       "button_add", &priv->button_add,
       "button_remove", &priv->button_remove,
       "button_import", &priv->button_import,
-      "hbox_protocol", &priv->hbox_protocol,
       "notebook_account", &priv->notebook_account,
       "alignment_loading", &alig,
       "accounts_sw", &sw,
@@ -2225,8 +2350,6 @@ accounts_dialog_build_ui (EmpathyAccountsDialog *dialog)
       NULL);
   g_free (filename);
 
-  gtk_widget_set_no_show_all (priv->frame_no_protocol, TRUE);
-
   empathy_builder_connect (gui, dialog,
       "button_add", "clicked", accounts_dialog_button_add_clicked_cb,
       "button_remove", "clicked", accounts_dialog_button_remove_clicked_cb,
@@ -2308,7 +2431,7 @@ accounts_dialog_build_ui (EmpathyAccountsDialog *dialog)
             TP_CONNECTION_PRESENCE_TYPE_OFFLINE), GTK_ICON_SIZE_SMALL_TOOLBAR);
 
   priv->label_status = gtk_label_new (NULL);
-  gtk_label_set_line_wrap (GTK_LABEL (priv->label_status), TRUE);
+  gtk_label_set_ellipsize (GTK_LABEL (priv->label_status), PANGO_ELLIPSIZE_END);
 
   gtk_box_pack_start (GTK_BOX (hbox), priv->throbber, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), priv->image_status, FALSE, FALSE, 0);
