@@ -30,9 +30,11 @@
 #include <clutter-gtk/clutter-gtk.h>
 #include <clutter-gst/clutter-gst.h>
 
-#include <telepathy-glib/debug-sender.h>
+#ifdef CLUTTER_WINDOWING_X11
+#include <X11/Xlib.h>
+#endif
 
-#include <telepathy-yell/telepathy-yell.h>
+#include <telepathy-glib/debug-sender.h>
 
 #include <libempathy/empathy-client-factory.h>
 
@@ -87,7 +89,7 @@ find_window_for_handle (gpointer key,
 static gboolean
 incoming_call_cb (EmpathyCallFactory *factory,
     guint handle,
-    TpyCallChannel *channel,
+    TpCallChannel *channel,
     TpChannelDispatchOperation *dispatch_operation,
     TpAddDispatchOperationContext *context,
     gpointer user_data)
@@ -187,6 +189,12 @@ main (int argc,
   /* Init */
   g_thread_init (NULL);
 
+#ifdef GDK_WINDOWING_X11
+  /* We can't call clutter_gst_init() before gtk_clutter_init(), so no choice
+   * but to intiialise X11 threading ourself */
+  XInitThreads ();
+#endif
+
   /* Clutter needs this */
   gdk_disable_multidevice ();
 
@@ -209,8 +217,6 @@ main (int argc,
 
   g_option_context_free (optcontext);
 
-  tpy_cli_init ();
-
   gtk_clutter_init (&argc, &argv);
   clutter_gst_init (&argc, &argv);
 
