@@ -67,7 +67,7 @@ struct _EmpathyPreferencesPriv {
 
 	GtkWidget *checkbutton_show_smileys;
 	GtkWidget *checkbutton_show_contacts_in_rooms;
-	GtkWidget *checkbutton_separate_chat_windows;
+	GtkWidget *radiobutton_chats_new_windows;
 	GtkWidget *checkbutton_events_notif_area;
 	GtkWidget *checkbutton_autoconnect;
 	GtkWidget *checkbutton_logging;
@@ -166,7 +166,7 @@ static SoundEventEntry sound_entries [] = {
 	{ N_("Message received"), EMPATHY_PREFS_SOUNDS_INCOMING_MESSAGE },
 	{ N_("Message sent"), EMPATHY_PREFS_SOUNDS_OUTGOING_MESSAGE },
 	{ N_("New conversation"), EMPATHY_PREFS_SOUNDS_NEW_CONVERSATION },
-	{ N_("Contact goes online"), EMPATHY_PREFS_SOUNDS_CONTACT_LOGIN },
+	{ N_("Contact comes online"), EMPATHY_PREFS_SOUNDS_CONTACT_LOGIN },
 	{ N_("Contact goes offline"), EMPATHY_PREFS_SOUNDS_CONTACT_LOGOUT },
 	{ N_("Account connected"), EMPATHY_PREFS_SOUNDS_SERVICE_LOGIN },
 	{ N_("Account disconnected"), EMPATHY_PREFS_SOUNDS_SERVICE_LOGOUT }
@@ -248,7 +248,7 @@ preferences_setup_widgets (EmpathyPreferences *preferences)
 
 	g_settings_bind (priv->gsettings_ui,
 			 EMPATHY_PREFS_UI_SEPARATE_CHAT_WINDOWS,
-			 priv->checkbutton_separate_chat_windows,
+			 priv->radiobutton_chats_new_windows,
 			 "active",
 			 G_SETTINGS_BIND_DEFAULT);
 
@@ -678,7 +678,8 @@ static void
 preferences_preview_theme_append_message (EmpathyChatView *view,
 					  EmpathyContact *sender,
 					  EmpathyContact *receiver,
-					  const gchar *text)
+					  const gchar *text,
+					  gboolean should_highlight)
 {
 	EmpathyMessage *message;
 
@@ -688,7 +689,7 @@ preferences_preview_theme_append_message (EmpathyChatView *view,
 		"body", text,
 		NULL);
 
-	empathy_chat_view_append_message (view, message);
+	empathy_chat_view_append_message (view, message, should_highlight);
 	g_object_unref (message);
 }
 
@@ -735,19 +736,20 @@ preferences_preview_theme_changed_cb (EmpathyThemeManager *manager,
 
 	preferences_preview_theme_append_message (priv->chat_theme_preview,
 		/* translators: Quote from Romeo & Julier, for chat theme preview */
-		juliet, romeo, _("O Romeo, Romeo, wherefore art thou Romeo?"));
+		juliet, romeo, _("O Romeo, Romeo, wherefore art thou Romeo?"),
+		TRUE /* this message mentions Romeo */);
 	preferences_preview_theme_append_message (priv->chat_theme_preview,
 		/* translators: Quote from Romeo & Julier, for chat theme preview */
-		juliet, romeo, _("Deny thy father and refuse thy name;"));
+		juliet, romeo, _("Deny thy father and refuse thy name;"), FALSE);
 	preferences_preview_theme_append_message (priv->chat_theme_preview,
 		/* translators: Quote from Romeo & Julier, for chat theme preview */
-		juliet, romeo, _("Or if thou wilt not, be but sworn my love"));
+		juliet, romeo, _("Or if thou wilt not, be but sworn my love"), FALSE);
 	preferences_preview_theme_append_message (priv->chat_theme_preview,
 		/* translators: Quote from Romeo & Julier, for chat theme preview */
-		juliet, romeo, _("And I'll no longer be a Capulet."));
+		juliet, romeo, _("And I'll no longer be a Capulet."), FALSE);
 	preferences_preview_theme_append_message (priv->chat_theme_preview,
 		/* translators: Quote from Romeo & Julier, for chat theme preview */
-		romeo, juliet, _("Shall I hear more, or shall I speak at this?"));
+		romeo, juliet, _("Shall I hear more, or shall I speak at this?"), FALSE);
 
 	/* translators: Quote from Romeo & Julier, for chat theme preview */
 	empathy_chat_view_append_event (priv->chat_theme_preview, _("Juliet has disconnected"));
@@ -1170,7 +1172,7 @@ empathy_preferences_init (EmpathyPreferences *preferences)
 		"combobox_chat_theme_variant", &priv->combobox_chat_theme_variant,
 		"hbox_chat_theme_variant", &priv->hbox_chat_theme_variant,
 		"sw_chat_theme_preview", &priv->sw_chat_theme_preview,
-		"checkbutton_separate_chat_windows", &priv->checkbutton_separate_chat_windows,
+		"radiobutton_chats_new_windows", &priv->radiobutton_chats_new_windows,
 		"checkbutton_events_notif_area", &priv->checkbutton_events_notif_area,
 		"checkbutton_autoconnect", &priv->checkbutton_autoconnect,
 		"checkbutton_logging", &priv->checkbutton_logging,
